@@ -22,10 +22,10 @@ use std::path::PathBuf;
 use std::sync::RwLock;
 
 /// Name of this executable (without the Windows ".exe" extension).
-const CURRENT_EXE: &str = "tp-note";
+const CURRENT_EXE: &str = "tpnote";
 
 /// Tp-Note's configuration file filename.
-const CONFIG_FILENAME: &str = "tp-note.toml";
+const CONFIG_FILENAME: &str = "tpnote.toml";
 
 /// Default value for command line option `--debug`.  Determines the maximum
 /// debug level events must have, to be logged.  If the command line option
@@ -41,13 +41,22 @@ const ARG_DEFAULT_EDITOR: bool = false;
 /// If set to `true`, the corresponding command line flag is ignored.
 const ARG_DEFAULT_NO_FILENAME_SYNC: bool = false;
 
-/// Default value for command line flag `--popup` If the command line flag
+/// Default value for command line flag `--popup`. If the command line flag
 /// `--popup` or `POPUP` is `true`, all log events will also trigger the
 /// appearance of a popup alert window.  Note, that error level debug events
 /// will always pop up, regardless of `--popup` and `POPUP` (unless
 /// `--debug=off`).
 const ARG_DEFAULT_POPUP: bool = true;
 
+/// Default value for command line flag `--tty`. _Tp-Note_ tries different
+/// heuristics to detect weather a graphic environment is available or not. For
+/// example, under Linux, the '`DISPLAY`' environment variable is evaluated. The
+/// '`--tty`' flag disables the automatic detection and sets _Tp-Note_ in
+/// "console" mode, where only the non GUI editor (see configuration variable:
+/// '`[app_args] editor_console`') and no viewer is launched. If this is set
+/// to `true` _Tp-Note_ starts in console mode permanently.
+const ARG_DEFAULT_TTY: bool = false;
+
 /// Maximum length of a note's filename in bytes. If a filename template produces
 /// a longer string, it will be truncated.
 #[cfg(not(test))]
@@ -700,6 +709,7 @@ pub struct ArgDefault {
     pub edit: bool,
     pub no_filename_sync: bool,
     pub popup: bool,
+    pub tty: bool,
 }
 
 /// Configuration of filename parsing, deserialized from the
@@ -802,6 +812,7 @@ impl ::std::default::Default for ArgDefault {
             edit: ARG_DEFAULT_EDITOR,
             no_filename_sync: ARG_DEFAULT_NO_FILENAME_SYNC,
             popup: ARG_DEFAULT_POPUP,
+            tty: ARG_DEFAULT_TTY,
         }
     }
 }
